<?xml version="1.0" encoding="UTF-8"?>

<xsl:stylesheet version="1.0"
        exclude-result-prefixes="xhtml xforms ev"
		xmlns="http://www.w3.org/1999/xhtml"
		xmlns:xhtml="http://www.w3.org/1999/xhtml"
		xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
		xmlns:ajx="http://www.ajaxforms.net/2006/ajx"
		xmlns:xforms="http://www.w3.org/2002/xforms"
		xmlns:ev="http://www.w3.org/2001/xml-events">

    <xsl:output encoding="UTF-8" indent="yes"/>
    <xsl:strip-space elements="*"/>
    <xsl:param name="resourcesdir"/>

    <xsl:template match="xhtml:html">
        <html>
        	<xsl:copy-of select="@*"/>
            <head>
	            <xsl:copy-of select="xhtml:head/@*"/>

<script language="javascript">
var Core = {
    fileName : 'ajaxforms.js',
    getAbsolutePos : function(e) {
        var r = Core.getPos(e);

        if (e.offsetParent) {
            var tmp = Core.getAbsolutePos(e.offsetParent);
            r.x += tmp.x;
            r.y += tmp.y;
        }

        return r;
    },
    setPos : function(element, left, top) {
        if (element.offsetParent) {
            var tmp = Core.getAbsolutePos(element.offsetParent);
            left -= tmp.x;
            top -= tmp.y;
        }

        element.style.top = top + "px";
        element.style.left = left + "px";
    },
    getWindowSize : function() {
        return {
            height : document.body.clientHeight || document.documentElement.clientHeight || window.innerHeight || 0,
            width : document.body.clientWidth || document.documentElement.clientWidth || window.innerWidth || 0
        };
    }
};
</script> 

<script language="javascript">
var Dialog = {
    dialogs : [],
    init : false,
    show1 : function(div, parent) {
        if (parent) {
            var absPos = Core.getAbsolutePos(parent);
            Core.setPos(div, absPos.x, (absPos.y + parent.offsetHeight));
        } else {        
       		var size = Core.getWindowSize();
       		var h = (size.height - div.offsetHeight) / 2;
  
          if (!inArray(div, this.dialogs)) {
              this.dialogs.push(div);
          }
        }
    }
};
</script> 

                <script src="{$resourcesdir}ajaxforms.js" type="text/javascript"/>
                <link type="text/css" href="{$resourcesdir}ajaxforms.css" rel="stylesheet"/>
                <xsl:for-each select="//xforms:model/@schema">
                	<xsl:if test="not(starts-with(., '#'))">
	                	<script src="{substring-before(., '.')}.js"/>
	                </xsl:if>
                </xsl:for-each>
                <xsl:apply-templates select="xhtml:head/xhtml:*"/>
            </head>
            <body onload="init();">
	            <xsl:copy-of select="xhtml:body/@*"/>
                <div id="statusPanel">... Loading ...</div>
                <xsl:apply-templates select=".//xforms:message|.//ajx:confirm"/>
                <xsl:apply-templates select="xhtml:body/*"/>
                <script type="text/javascript">Dialog.show1('statusPanel');</script>
            </body>
        </html>
	</xsl:template>

    <xsl:template match="xforms:setvalue|xforms:insert|xforms:delete|xforms:action|xforms:toggle|xforms:send|xforms:setfocus"/>
    
    <xsl:template match="xforms:reset|xforms:refresh|xforms:rebuild|xforms:recalculate|xforms:revalidate"/>
    
    <xsl:template match="ajx:show|ajx:hide|ajx:start|ajx:stop"/>

    <xsl:template match="xforms:group">
		<xsl:call-template name="group"/>
	</xsl:template>

    <xsl:template match="xforms:repeat">
		<xsl:call-template name="group">
			<xsl:with-param name="type" select="'repeat'"/>
		</xsl:call-template>
	</xsl:template>

    <xsl:template match="xforms:message|ajx:confirm">
		<span id="{@id}" class="xforms-message">
			<xsl:apply-templates/>
		</span>
	</xsl:template>

    <xsl:template match="xforms:label">
		<xsl:param name="appearance" select="false()"/>
		<xsl:choose>
			<xsl:when test="$appearance = 'groupTitle'">
				<div>
                    <xsl:call-template name="comunLabel"><xsl:with-param name="class">xforms-group-label</xsl:with-param></xsl:call-template>
                    <xsl:choose>
                    	<xsl:when test="count(./node()) > 0"><xsl:apply-templates /></xsl:when>
						<xsl:otherwise>&#160;</xsl:otherwise>
					</xsl:choose>
				</div>
			</xsl:when>
			<xsl:when test="$appearance = 'treeLabel'">
				<div>
                    <xsl:call-template name="comunLabel"><xsl:with-param name="class">xforms-tree-label</xsl:with-param></xsl:call-template>
                    <xsl:choose>
                    	<xsl:when test="count(./node()) > 0"><xsl:apply-templates /></xsl:when>
						<xsl:otherwise>&#160;</xsl:otherwise>
					</xsl:choose>
				</div>
			</xsl:when>
			<xsl:when test="$appearance = 'itemTreeLabel'">
				<a>
                    <xsl:call-template name="comunLabel"><xsl:with-param name="class">xforms-tree-item-label</xsl:with-param></xsl:call-template>
                    <xsl:choose>
                    	<xsl:when test="count(./node()) > 0"><xsl:apply-templates /></xsl:when>
						<xsl:otherwise>&#160;</xsl:otherwise>
					</xsl:choose>
				</a>
			</xsl:when>
			<xsl:when test="$appearance = 'minimal'">
				<legend>
                    <xsl:call-template name="comunLabel"/>
                    <xsl:choose>
                    	<xsl:when test="count(./node()) > 0"><xsl:apply-templates /></xsl:when>
						<xsl:otherwise>&#160;</xsl:otherwise>
					</xsl:choose>
				</legend>
			</xsl:when>
			<xsl:when test="$appearance = 'caption'">
				<caption>
                    <xsl:call-template name="comunLabel"/>
                    <xsl:choose>
                    	<xsl:when test="count(./node()) > 0"><xsl:apply-templates /></xsl:when>
						<xsl:otherwise>&#160;</xsl:otherwise>
					</xsl:choose>
				</caption>
			</xsl:when>
			<xsl:when test="$appearance = 'table'">
				<th scope="col">
					<xsl:call-template name="comunLabel"/>
                    <xsl:choose>
                    	<xsl:when test="count(./node()) > 0"><xsl:apply-templates /></xsl:when>
						<xsl:otherwise>&#160;</xsl:otherwise>
					</xsl:choose>
				</th>
			</xsl:when>
            <xsl:when test="$appearance = 'item'">
				<span>
					<xsl:call-template name="style">
						<xsl:with-param name="class">xforms-item-label</xsl:with-param>
					</xsl:call-template>
                    <xsl:choose>
                    	<xsl:when test="count(./node()) > 0"><xsl:apply-templates /></xsl:when>
						<xsl:otherwise>&#160;</xsl:otherwise>
					</xsl:choose>
				</span>
			</xsl:when>
            <xsl:when test="$appearance = 'field-minimal'">
				<label>
					<xsl:call-template name="comunLabel">
						<xsl:with-param name="class">xforms-appearance-minimal</xsl:with-param>
					</xsl:call-template>
                    <xsl:choose>
                    	<xsl:when test="count(./node()) > 0"><xsl:apply-templates /></xsl:when>
						<xsl:otherwise>&#160;</xsl:otherwise>
					</xsl:choose>
				</label>
			</xsl:when>
            <xsl:when test="$appearance = 'tabs'">
				<a href="#" onclick="XFToggle.toggle('{../@id}');">
                    <xsl:call-template name="comunLabel"/>
                    <xsl:choose>
                    	<xsl:when test="count(./node()) > 0"><xsl:apply-templates /></xsl:when>
						<xsl:otherwise>&#160;</xsl:otherwise>
					</xsl:choose>
                </a>
			</xsl:when>
			<xsl:when test="$appearance = 'span'">
				<span>
                    <xsl:call-template name="comunLabel"/>
                    <xsl:choose>
                    	<xsl:when test="count(./node()) > 0"><xsl:apply-templates /></xsl:when>
						<xsl:otherwise>&#160;</xsl:otherwise>
					</xsl:choose>
				</span>
			</xsl:when>
            <xsl:when test="local-name(../..) = 'tabs' or $appearance = 'none' or $appearance = 'groupNone'" />
			<xsl:otherwise>
				<label>
					<xsl:call-template name="comunLabel"/>
                    <xsl:choose>
                    	<xsl:when test="count(./node()) > 0"><xsl:apply-templates /></xsl:when>
						<xsl:otherwise>&#160;</xsl:otherwise>
					</xsl:choose>
				</label>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
    <xsl:template match="xforms:input">
		<xsl:param name="appearance" select="false()"/>
		<xsl:call-template name="field">
			<xsl:with-param name="appearance" select="$appearance"/>
			<xsl:with-param name="body">
				<input type="text">
					<xsl:call-template name="comun"/>
				</input>
			</xsl:with-param>
		</xsl:call-template>
	</xsl:template>

    <xsl:template match="xforms:secret">
		<xsl:param name="appearance" select="false()"/>
		<xsl:call-template name="field">
			<xsl:with-param name="appearance" select="$appearance"/>
			<xsl:with-param name="body">
				<input type="password">
					<xsl:call-template name="comun"/>
				</input>
			</xsl:with-param>
		</xsl:call-template>
	</xsl:template>

    <xsl:template match="xforms:output">
		<xsl:param name="appearance" select="false()"/>
		<xsl:choose>
			<xsl:when test="xforms:label or xforms:hint or xforms:help">
				<xsl:call-template name="field">
					<xsl:with-param name="appearance" select="$appearance"/>
					<xsl:with-param name="body">
						<xsl:choose>
						    <xsl:when test="@mediatype = 'image/*'">
								<img>
							    	<xsl:call-template name="comun"/>
								</img>
						    </xsl:when>
						    <xsl:otherwise>
								<span>
				                    <xsl:call-template name="comun"/>&#160;
								</span>
						    </xsl:otherwise>
						</xsl:choose>
					</xsl:with-param>
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<span>
					<xsl:call-template name="style">
						<xsl:with-param name="class">xforms-control xforms-output</xsl:with-param>
					</xsl:call-template>
					<xsl:choose>
					    <xsl:when test="@mediatype = 'image/*'">
							<img>
						    	<xsl:call-template name="comun"/>
							</img>
					    </xsl:when>
					    <xsl:otherwise>
							<span>
			                    <xsl:call-template name="comun"/>&#160;
							</span>
					    </xsl:otherwise>
					</xsl:choose>
					<xsl:if test="local-name(..) != 'alert' and local-name(..) != 'label' and local-name(..) != 'hint' and local-name(..) != 'help'">
			            <span class="xforms-alert">
			                <span class="xforms-alert-icon">
				                <xsl:if test="xforms:alert">
				                    <xsl:attribute name="onmouseover">show(this, null, true)</xsl:attribute>
				                    <xsl:attribute name="onmouseout">show(this, null, false)</xsl:attribute>
				                </xsl:if>
			                </span>
			                <xsl:if test="xforms:alert">
			             		<div class="xforms-alert-value" id="{xforms:alert/@id}">
			                 		<xsl:apply-templates select="xforms:alert/node()"/>
			                    </div>
			   		        </xsl:if>
			       		</span>
			       	</xsl:if>
				</span>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

    <xsl:template match="xforms:textarea">
		<xsl:param name="appearance" select="false()"/>
		<xsl:call-template name="field">
			<xsl:with-param name="appearance" select="$appearance"/>
			<xsl:with-param name="body">
				<textarea>
					<xsl:call-template name="comun"/>&#160;
				</textarea>
			</xsl:with-param>
		</xsl:call-template>
	</xsl:template>

	<xsl:template match="xforms:trigger|xforms:submit">
		<xsl:call-template name="field">
			<xsl:with-param name="appearance">none</xsl:with-param>
			<xsl:with-param name="body">
                <xsl:choose>
                    <xsl:when test="@appearance = 'minimal'">
                        <a href="#">
                            <xsl:apply-templates select="xforms:label">
	                            <xsl:with-param name="appearance" select="'span'"/>
                            </xsl:apply-templates>
                        </a>
                    </xsl:when>
                    <xsl:otherwise>
                		<button>
                			<xsl:apply-templates select="xforms:label">
	                            <xsl:with-param name="appearance" select="'span'"/>
                			</xsl:apply-templates>
                		</button>
                    </xsl:otherwise>
                </xsl:choose>
			</xsl:with-param>
		</xsl:call-template>
	</xsl:template>

    <xsl:template match="xforms:select1|xforms:select">
		<xsl:param name="appearance" select="false()"/>
		<xsl:call-template name="field">
			<xsl:with-param name="appearance" select="$appearance"/>
			<xsl:with-param name="body">
				<xsl:choose>
                    <xsl:when test="@appearance='compact'">
                        <select size="4">
		                    <xsl:call-template name="comun"/>
                            <xsl:if test="local-name() = 'select'">
                                <xsl:attribute name="multiple">true</xsl:attribute>
                            </xsl:if>
                            <xsl:apply-templates select="xforms:item|xforms:itemset"/>
                        </select>
                    </xsl:when>
                    <xsl:when test="@appearance='minimal'">
                        <select>
							<xsl:call-template name="comun"/>
                            <xsl:if test="local-name() = 'select'">
                                <xsl:attribute name="multiple">true</xsl:attribute>
                                <xsl:attribute name="size"><xsl:value-of select="count(child::xforms:item)"/></xsl:attribute>
                            </xsl:if>
                            <xsl:apply-templates select="xforms:item|xforms:itemset"/>
                        </select>
                    </xsl:when>
                    <xsl:otherwise>
                        <span>
		                    <xsl:call-template name="comun"/>
                            <xsl:apply-templates select="xforms:item|xforms:itemset">
                                <xsl:with-param name="type"><xsl:choose>
                                    <xsl:when test="local-name() = 'select'">checkbox</xsl:when>
                                    <xsl:otherwise>radio</xsl:otherwise>
                                </xsl:choose></xsl:with-param> 
                            </xsl:apply-templates>
                        </span>
                    </xsl:otherwise>
                </xsl:choose>
			</xsl:with-param>
		</xsl:call-template>
	</xsl:template>
	
    <xsl:template match="xforms:item">
        <xsl:param name="type" select="false()" /> 
        <xsl:choose>
            <xsl:when test="$type">
                <div>
                    <xsl:call-template name="style"><xsl:with-param name="class">xforms-item</xsl:with-param></xsl:call-template>
                    <input type="{$type}" value="{xforms:value}">
                    	<xsl:call-template name="comun"/>
                    </input>
                    <xsl:apply-templates select="xforms:label">
                        <xsl:with-param name="appearance">item</xsl:with-param>
                    </xsl:apply-templates>
                </div>
            </xsl:when>
            <xsl:otherwise>
                <option value="{xforms:value}" id="{@id}">
                    <xsl:value-of select="xforms:label" />
                </option>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>

    <xsl:template match="xforms:itemset">
        <xsl:param name="type" select="false()" /> 
        <xsl:choose>
            <xsl:when test="$type">
                <div>
                    <xsl:call-template name="style"><xsl:with-param name="class">xforms-itemset</xsl:with-param></xsl:call-template>
                    <div class="xforms-item" id="{xforms:value/@id}">
                        <input type="{$type}" value="{xforms:value}"></input>
                        <xsl:apply-templates select="xforms:label">
                            <xsl:with-param name="appearance">item</xsl:with-param>
                        </xsl:apply-templates>
                    </div>
                </div>
            </xsl:when>
            <xsl:otherwise>
                <option id="{@id}">...Loading...</option>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>

	<xsl:template match="xforms:switch">
		<div>
		    <xsl:call-template name="style">
                <xsl:with-param name="class">xforms-switch</xsl:with-param>
            </xsl:call-template>
			<xsl:for-each select="xforms:case">
				<div>
					<xsl:call-template name="style">
						<xsl:with-param name="class">xforms-case</xsl:with-param>
					</xsl:call-template>
					<xsl:if test="not(@selected | @selected = 'true')">
						<xsl:attribute name="style">display:none;</xsl:attribute>
					</xsl:if>
					<xsl:apply-templates/>
				</div>
			</xsl:for-each>
		</div>
	</xsl:template>

	<xsl:template match="ajx:tabs">
		<div>
			<xsl:call-template name="style">
				<xsl:with-param name="class">ajx-tabs</xsl:with-param>
			</xsl:call-template>
			<ul class="ajx-tabs-list">
				<xsl:for-each select="ajx:tab">
					<li>
						<xsl:if test="@selected = 'true'"><xsl:attribute name="class">ajx-tab-selected</xsl:attribute></xsl:if>
						<xsl:apply-templates select="xforms:label">
							<xsl:with-param name="appearance">tabs</xsl:with-param>
						</xsl:apply-templates>
					</li>
				</xsl:for-each>
			</ul>
			<xsl:for-each select="ajx:tab">
				<div>
					<xsl:call-template name="style">
						<xsl:with-param name="class">ajx-tab</xsl:with-param>
					</xsl:call-template>
					<xsl:if test="not(@selected | @selected = 'true')">
						<xsl:attribute name="style">display:none;</xsl:attribute>
					</xsl:if>
					<xsl:apply-templates />
				</div>
			</xsl:for-each>
		</div>
	</xsl:template>

    <xsl:template match="xforms:tree">
		<div>
			<xsl:call-template name="style"><xsl:with-param name="class">xforms-tree</xsl:with-param></xsl:call-template>
			<xsl:apply-templates select="xforms:label"><xsl:with-param name="appearance">treeLabel</xsl:with-param></xsl:apply-templates>
		    <ul>
		    	<li class="xforms-tree-item">
		    		<span class="xforms-tree-item-button">&#160;</span>
					<xsl:apply-templates select="xforms:item/xforms:label">
						<xsl:with-param name="appearance">itemTreeLabel</xsl:with-param>
					</xsl:apply-templates>
		    	</li>
		    </ul>
		</div>
	</xsl:template>

	<xsl:template match="ajx:dialog">
		<div>
			<xsl:call-template name="style"><xsl:with-param name="class">ajx-dialog</xsl:with-param></xsl:call-template>
			<xsl:apply-templates>
  				<xsl:with-param name="appearance" select="'groupTitle'"/>
			</xsl:apply-templates>
		</div>
	</xsl:template>

	<xsl:template match="node()|@*" priority="-1">
		<xsl:param name="appearance" select="@appearance"/>
		<xsl:copy>
			<xsl:apply-templates select="@*"/>
			<xsl:apply-templates>
				<xsl:with-param name="appearance" select="$appearance"/>
			</xsl:apply-templates>
		</xsl:copy>
	</xsl:template>

    <xsl:template name="field">
		<xsl:param name="appearance" select="false()"/>
		<xsl:param name="body"/>
		<table>
			<xsl:call-template name="style">
				<xsl:with-param name="class">xforms-control xforms-<xsl:value-of select="local-name()"/><xsl:if test="$appearance = 'minimal' or local-name() = 'trigger' or local-name() = 'submit' or not(xforms:label)"> xforms-appearance-minimal</xsl:if></xsl:with-param>
			</xsl:call-template>
			<tr>
				<xsl:if test="local-name() != 'trigger' and local-name() != 'submit' and (local-name() != 'output' or (xforms:label and $appearance != 'none'))">
					<td class="focus"></td>
				</xsl:if>
				<xsl:if test="xforms:label and $appearance != 'none'">
					<td>
						<xsl:apply-templates select="xforms:label"/>
					</td>
				</xsl:if>
				<td class="value"><xsl:copy-of select="$body"/></td>
				<td>
					<xsl:if test="@ajx:aid-button = 'true'">
						<button class="aid-button">...</button>
					</xsl:if>
		            <xsl:if test="local-name() != 'output'">
		        		<span class="xforms-required-icon">*</span>
		            </xsl:if>
		            <span class="xforms-alert">
		                <span class="xforms-alert-icon">
			                <xsl:if test="xforms:alert">
			                    <xsl:attribute name="onmouseover">show(this, null, true)</xsl:attribute>
			                    <xsl:attribute name="onmouseout">show(this, null, false)</xsl:attribute>
			                </xsl:if>
		                </span>
		                <xsl:if test="xforms:alert">
		             		<div class="xforms-alert-value" id="{xforms:alert/@id}">
		                 		<xsl:apply-templates select="xforms:alert/node()"/>
		                    </div>
		   		        </xsl:if>
		       		</span>
		   			<xsl:if test="xforms:hint">
		       			<span class="xforms-hint">
			       			<span class="xforms-hint-icon" onmouseover="show(this, 'hint', true)" onmouseout="show(this, 'hint', false)"/>
					        <div class="xforms-hint-value" id="{xforms:hint/@id}">
		                 		<xsl:apply-templates select="xforms:hint/node()"/>
		                    </div>
		   				</span>
		       		</xsl:if>
		   			<xsl:if test="xforms:help">
		       			<span class="xforms-help">
			       			<span class="xforms-help-icon" onmouseover="show(this, 'help', true)" onmouseout="show(this, 'help', false)"/>
					        <div class="xforms-help-value" id="{xforms:help/@id}">
		                 		<xsl:apply-templates select="xforms:help/node()"/>
		                    </div>
		   				</span>
		       		</xsl:if>
		       	</td>
		    </tr>
		</table>
	</xsl:template>
	                    	
    <xsl:template name="group">
		<xsl:param name="type" select="'group'"/>
		<xsl:param name="appearance" select="@appearance"/>
		<xsl:choose>
			<xsl:when test="$appearance = 'compact'">
				<table>
     				<xsl:call-template name="style"><xsl:with-param name="class">xforms-<xsl:value-of select="$type"/></xsl:with-param></xsl:call-template>
					<xsl:if test="$type = 'case' and not(@selected | @selected = 'true')">
					    <xsl:attribute name="style">display:none;</xsl:attribute>
					</xsl:if>
					<xsl:if test="xforms:label">
 						<xsl:apply-templates select="xforms:label">
						    <xsl:with-param name="appearance" select="'caption'"/>
					    </xsl:apply-templates>
					</xsl:if>
					<thead>
 					    <tr>
					        <xsl:for-each select="xforms:*">
					        	<xsl:choose>
						        	<xsl:when test="(not(xforms:label) and local-name() != 'label') or local-name() = 'trigger' or local-name() = 'submit'">
							        	<th scope="col" class="xforms-label"/>
						        	</xsl:when>
						        	<xsl:otherwise>
									    <xsl:apply-templates select="xforms:label">
										    <xsl:with-param name="appearance" select="'table'"/>
									    </xsl:apply-templates>
									</xsl:otherwise>
								</xsl:choose>
						    </xsl:for-each>
					    </tr>
					</thead>
					<tbody>
					    <tr>
					    	<xsl:if test="$type = 'repeat'">
					    		<xsl:attribute name="class">xforms-repeat-item</xsl:attribute>
					    	</xsl:if>
						    <xsl:for-each select="xforms:input|xforms:output|xforms:select|xforms:select1|xforms:textarea|xforms:secret|xforms:group|xforms:repeat|xforms:switch|xforms:trigger|xforms:submit">
							    <td class="td-cell">
							    	<xsl:apply-templates select=".">
									   <xsl:with-param name="appearance" select="'none'"/>
								    </xsl:apply-templates>
							    </td>
						    </xsl:for-each>
 					    </tr>
					</tbody>
				</table>
			</xsl:when>
			<xsl:when test="$type = 'repeat'">
                <ul>
                    <xsl:call-template name="style"><xsl:with-param name="class">xforms-repeat</xsl:with-param></xsl:call-template>
					<li class="xforms-repeat-item">
			            <xsl:apply-templates>
			            	<xsl:with-param name="appearance"><xsl:if test="$appearance = 'minimal'">minimal</xsl:if></xsl:with-param>
			            </xsl:apply-templates>
					</li>
				</ul>
			</xsl:when>
			<xsl:when test="$appearance = 'minimal'">
			    <fieldset>
				    <xsl:call-template name="style"><xsl:with-param name="class">xforms-<xsl:value-of select="$type"/></xsl:with-param></xsl:call-template>
					<xsl:if test="$type = 'case' and not(@selected | @selected = 'true')">
					    <xsl:attribute name="style">display:none;</xsl:attribute>
					</xsl:if>
					<xsl:apply-templates>
    					<xsl:with-param name="appearance">minimal</xsl:with-param>
					</xsl:apply-templates>
			    </fieldset>
			</xsl:when>
			<xsl:otherwise>
				<div>
				    <xsl:call-template name="style"><xsl:with-param name="class">xforms-<xsl:value-of select="$type"/></xsl:with-param></xsl:call-template>
					<xsl:if test="$type = 'case' and not(@selected | @selected = 'true')">
					    <xsl:attribute name="style">display:none;</xsl:attribute>
					</xsl:if>
					<xsl:apply-templates select="xforms:label">
    					<xsl:with-param name="appearance" select="'groupTitle'"/>
					</xsl:apply-templates>
				    <div class="xforms-{$type}-content">
						<xsl:apply-templates>
	    					<xsl:with-param name="appearance" select="'groupNone'"/>
						</xsl:apply-templates>
					</div>
				</div>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

    <xsl:template name="comun">
       	<xsl:attribute name="class">xforms-value</xsl:attribute>
	</xsl:template>

    <xsl:template name="comunLabel">
	    <xsl:param name="class"/>
	    <xsl:call-template name="style"><xsl:with-param name="class">xforms-label <xsl:value-of select="$class"/></xsl:with-param></xsl:call-template>
	  </xsl:template>

    <xsl:template name="style">
        <xsl:param name="class" select="_"/>
        <xsl:if test="@id">
	        <xsl:attribute name="id"><xsl:value-of select="@id"/></xsl:attribute>
  	    </xsl:if>
  	    <xsl:if test="@class or $class != ''">
  		    <xsl:attribute name="class"><xsl:if test="@class"><xsl:value-of select="concat(concat(@class, ' '), $class)"/></xsl:if><xsl:if test="not(@class)"><xsl:value-of select="$class"/></xsl:if></xsl:attribute>
  		  </xsl:if>
    </xsl:template>
</xsl:stylesheet>
